Generates reference based on analog input

Dependents:   locomotion_pid_action_refactor_EMG

Revision:
4:38af2aa14a3f
Parent:
3:43d9f8db93b7
Child:
5:7186da6f562f
diff -r 43d9f8db93b7 -r 38af2aa14a3f refGen.h
--- a/refGen.h	Fri Oct 20 16:28:30 2017 +0000
+++ b/refGen.h	Sun Oct 22 08:01:03 2017 +0000
@@ -2,12 +2,14 @@
 #define REFGEN_H
 
 #include "mbed.h"
+#include "biquadChain.h"
 
 
 class refGen {
 public:
     refGen(PinName, float); // Constructor sets up the pin to read the reference from
-    float getReferencePosition(); // Gets reference position on specified pin
+    float getReference(); // Gets reference position on specified pin
+    float getFilteredReference(biquadChain BQC); // Gets reference position and filters using filter specified as a biquadChain
     float maxAngle;
     bool r_direction;